@@ -20,34 +20,34 @@ local({
 #------------------------ Message boxes ----------------------#
 
 I.T<-function(){
- tkmessageBox(message="Correct.  This is a logical form of argument called \U0022modus ponens\U0022 \nor \U0022 affirming the antecedent\U0022.")}
+ tkmessageBox(message="Correct.  This is a logical form of argument called \U0022modus ponens\U0022 or \U0022 affirming the antecedent\U0022.")}
     
 I.F<-function(){
- tkmessageBox(message="Incorrect.  This is a logical form of argument called \U0022modus ponens\U0022 \nor \U0022 affirming the antecedent\U0022.", icon="error")}
+ tkmessageBox(message="Incorrect.  This is a logical form of argument called \U0022modus ponens\U0022 or \U0022 affirming the antecedent\U0022.", icon="error")}
 
 II.T<-function(){
- tkmessageBox(message="Correct.  This is a logical form of argument called \U0022modus tollens\U0022 or\n\U0022 denying the consequent\U0022.")}
+ tkmessageBox(message="Correct.  This is a logical form of argument called \U0022modus tollens\U0022 or \U0022 denying the consequent\U0022.")}
  
 II.F<-function(){
- tkmessageBox(message="Incorrect.  This is a logical form of argument called \U0022modus tollens\U0022 or\n\U0022 denying the consequent.\U0022", icon="error")}
+ tkmessageBox(message="Incorrect.  This is a logical form of argument called \U0022modus tollens\U0022 or \U0022 denying the consequent.\U0022", icon="error")}
 
 III.T<-function(){
- tkmessageBox(message="Incorrect.  This is an example of a fallacious type of argument \ncalled \U0022 affirming the consequent\U0022.", icon="error")}
+ tkmessageBox(message="Incorrect.  This is an example of a fallacious type of argument called \U0022 affirming the consequent\U0022.", icon="error")}
  
 III.F<-function(){
- tkmessageBox(message="Correct.  This is an example of a fallacious type of argument \ncalled \U0022 affirming the consequent\U0022.")}
+ tkmessageBox(message="Correct.  This is an example of a fallacious type of argument called \U0022 affirming the consequent\U0022.")}
 
 IV.T<-function(){
- tkmessageBox(message="Correct.  This is an example of a logical type of argument \ncalled \U0022 modus ponens\U0022.")}
+ tkmessageBox(message="Correct.  This is an example of a logical type of argument called \U0022 modus ponens\U0022.")}
  
 IV.F<-function(){
-  tkmessageBox(message="Inorrect.  This is a logical example of \U0022modus ponens\U0022 or\n\U0022 affirming the antecedent\U0022.", icon="error")}
+  tkmessageBox(message="Inorrect.  This is a logical example of \U0022modus ponens\U0022 or \U0022 affirming the antecedent\U0022.", icon="error")}
  
 V.T<-function(){
- tkmessageBox(message="Incorrect.  This is an example of a fallacious type of argument \ncalled \U0022 affirming the consequent\U0022.", icon="error")}
+ tkmessageBox(message="Incorrect.  This is an example of a fallacious type of argument called \U0022 affirming the consequent\U0022.", icon="error")}
  
 V.F<-function(){
- tkmessageBox(message="Correct.  This is an example of a fallacious type of argument called \n\U0022 affirming the consequent\U0022.")} 
+ tkmessageBox(message="Correct.  This is an example of a fallacious type of argument called \U0022 affirming the consequent\U0022.")} 
  
 VI.T<-function(){
  tkmessageBox(message="Incorrect.  No causality has been established. This is an example of a fallacious type of argument called \U0022post hoc ergo propter hoc\U0022.  Translated this means: \U0022 after this; therefore, because of this\U0022.", icon="error")}
